BehaviorFn

Struct BehaviorFn 

pub struct BehaviorFn<S, A, M, Sends, Br, E, I, F>
where A: Address, Br: BirthMode,
{ /* private fields */ }
A concrete behavior defined by initialization and user-event folds.

Each function is invoked exactly once for its corresponding input and its returned Actions value is preserved unchanged. This adapter adds no event routing or effect interpretation; those remain the responsibility of concrete behavior wrappers and the runtime interpreter.

Implementations

Source

impl<S, A, M, Sends, Br, E, I, F> BehaviorFn<S, A, M, Sends, Br, E, I, F>
where A: Address, Br: BirthMode, Sends: SendAlgebra, I: FnMut(&mut S) -> Result<Actions<A, Never, Sends, Br>, E>, F: FnMut(&mut S, A, M) -> Result<Actions<A, Never, Sends, Br>, E>,

pub fn new( state: S, initialize: I, transition: F, ) -> BehaviorFn<S, A, M, Sends, Br, E, I, F>

pub fn state(&self) -> &S