Supervisor

Struct Supervisor 

pub struct Supervisor<B, C>
where B: Behavior, C: Behavior<Ph = Never, Addr = <B as Behavior>::Addr>,
{ /* private fields */ }

Implementations

Source

impl<B, C> Supervisor<B, C>
where C: Behavior<Ph = Never, Addr = <B as Behavior>::Addr>, B: Behavior<Birth = Births<C>>,

pub fn new( inner: B, nonces: fn(usize) -> <<B as Behavior>::Addr as Address>::Nonce, count: usize, build: fn(usize) -> C, strategy: Strategy, policy: RestartPolicy, max_restarts: u32, window: Duration, ) -> Supervisor<B, C>

Construct the concrete supervisor behavior hidden by Compose.

Panics

Panics when configured child nonces are not unique. Such a topology would violate creator-local child routing and creation freshness before the behavior could return an initialization result.

pub fn with_strategy(self, strategy: Strategy) -> Supervisor<B, C>

pub fn with_policy(self, policy: RestartPolicy) -> Supervisor<B, C>

pub fn with_budget(self, max: u32, window: Duration) -> Supervisor<B, C>

pub fn with_failure_reaction( self, reaction: fn(&mut B, &SupervisionFailure<<B as Behavior>::Addr>) -> Result<Step<Never, Exit<<B as Behavior>::Addr>>, <B as Behavior>::Error>, ) -> Supervisor<B, C>

Replace the pure reaction used for typed supervision failures.

pub fn is_alive(&self, nonce: <<B as Behavior>::Addr as Address>::Nonce) -> bool

Report whether a known supervised proxy is alive.

Panics

Panics when nonce is not part of this supervisor topology.

pub fn child_count(&self) -> usize

pub fn restarts_in_window(&self) -> usize